init_standalone_runtimes

Function init_standalone_runtimes 

pub fn init_standalone_runtimes(options: &RuntimeOptions)
Initialize runtimes for a standalone process.

Query and ingest work share the global runtime. The scheduler is always constructed, with the global runtime size as its internal bound, and starts enabled according to configuration.