workload_scheduler_stats

Function workload_scheduler_stats 

pub fn workload_scheduler_stats() -> Option<SchedulerStats>
Returns scheduler counters when the experimental workload scheduler was constructed at startup, including while it is dynamically disabled.